=================================
``psyclone.psyir.backend.opencl``
=================================

.. automodule:: psyclone.psyir.backend.opencl

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.opencl
